#!/bin/bash

export LD_LIBRARY_PATH=/home/pi/despi
# ALSA equal plugin needs for some reason at least HOME set, which systemd does NOT set by default
# this causes an "operation not permitted" on open equal devices
export USER=root
export HOME=/root

# start script for pinball sound

# add user in gpio group for wiring pi
# usermod -a -G gpio pi
# remount boot and make it writeable for pi user
# umount /boot
# mount -o rw,fmask=0000,dmask=0000 /dev/mmcblk0p1 /boot

# usb stick support: detect if this path exists, if so use it as base path for update, soundset logging
BASEPATH=/boot
if [ -d /media/usb1/data ]; then
	BASEPATH=/media/usb1
fi
if [ -d /media/usb2/data ]; then
	BASEPATH=/media/usb2
fi
if [ -b /dev/sda ]; then
	BASEPATH=/media/usb1
fi

if [ -f $BASEPATH/data/options.txt ]; then
	OPTIONS=`cat $BASEPATH/data/options.txt`
fi

DESPI=despi

# check on /usr/lib/arm-linux-gnueabihf/libmicrohttpd*
for f in /usr/lib/arm-linux-gnueabihf/libmicrohttpd*; do
	DESPI=despi2
	OPTIONS="-H $OPTIONS"
    break
done

if [ -f /home/pi/despi/asound.conf ]; then
	cp -f /home/pi/despi/asound.conf /etc
	mv /home/pi/despi/asound.conf /home/pi/despi/asound.conf.copied
fi

if [ -d /home/pi/despi/dsp ] && [ ! -d $BASEPATH/data/dsp ]; then
	cp -f -r /home/pi/despi/dsp/ $BASEPATH/data/.
	mv /home/pi/despi/dsp /home/pi/despi/dsp.copied
fi

# make SDL use this audio device (in this case the USB sound card)
if [ -f $BASEPATH/data/use-usb.txt ]; then
	export AUDIODEV=hw:2,0
fi

# update handling
if [ -f $BASEPATH/update/update.zip ]; then
    mv $BASEPATH/update/update.zip $BASEPATH/update/update-done.zip
    unzip -o $BASEPATH/update/update-done.zip -d /home/pi
    sync
    /home/pi/despi/tiltaudio.sh
    exit 0
fi

export LUA_PATH=$BASEPATH/data/lua/?.lua
export LUA_CPATH=$BASEPATH/data/lua/?.so

# log rotate
mv $BASEPATH/data/raspin2.log $BASEPATH/data/raspin3.log 2>/dev/null
mv $BASEPATH/data/raspin1.log $BASEPATH/data/raspin2.log 2>/dev/null
mv $BASEPATH/data/raspin.log $BASEPATH/data/raspin1.log 2>/dev/null

# remove cores older than a day
find $BASEPATH/data/ -type f -mtime +1 -name 'core-*' -exec rm -f '{}' \;
# to avoid filling uo root files system
mv /home/pi/core-* $BASEPATH/data/
# reconfigure where to write core files
sysctl -q kernel.core_pattern=/home/pi/core-%e-%s-%t
# enable writing core files
ulimit -c unlimited

# default DSP firmware
DSPXML=/home/pi/despi/dsp/tiltaudio.xml
# look for a custom firmware
if [ -f $BASEPATH/data/dsp/tiltaudio.xml ]; then
		DSPXML="$BASEPATH/data/dsp/tiltaudio.xml"
fi

if /home/pi/despi/sigma_loader $DSPXML; then
		export ADAU1701=TRUE
    dtoverlay adau1701-i2s
		OPTIONS="-X $DSPXML $OPTIONS"
else
    dtoverlay hifiberry-dac
fi

cd /home/pi/despi

if openocd -f test.cfg; then
  echo "STM32F4 detected on SPI port"
  /home/pi/despi/update_check /home/pi/despi
fi

/home/pi/despi/$DESPI $OPTIONS -f $BASEPATH/data/raspin.log $BASEPATH/data/sound
